@@ -32,26 +32,15 @@ class DormitoryRoom(Base):
     """
     __tablename__ = 'univer_dormitory_rooms'
 
-    # Идентификатор
-    id = Column('dormitory_room_id', Integer, primary_key=True)
-
-    # Общежитие
+    id = Column('dormitory_room_id', Integer, primary_key=True)  # Идентификатор
     dormitory_id = Column(ForeignKey('platonus_univer_dormitories.dormitoryID'))
-    dormitory = relationship('Dormitory')
-
-    # Этаж
-    floor = Column('dormitory_room_floor', Integer)
-
-    # Вместимость
-    size = Column('dormitory_room_size', Integer)
-
-    # Наименование
-    number_ru = Column('dormitory_room_number_ru', String(30))
-    number_kz = Column('dormitory_room_number_kz', String(30))
-    number_en = Column('dormitory_room_number_en', String(30))
-
-    # Статус
-    status = Column(Integer)
+    dormitory = relationship('Dormitory')  # Общежитие
+    floor = Column('dormitory_room_floor', Integer)  # Этаж
+    size = Column('dormitory_room_size', Integer)  # Вместимость
+    number_ru = Column('dormitory_room_number_ru', String(30))  # Наименование комнаты (на русском)
+    number_kz = Column('dormitory_room_number_kz', String(30))  # Наименование комнаты (на казахском)
+    number_en = Column('dormitory_room_number_en', String(30))  # Наименование комнаты (на английском)
+    status = Column(Integer)  # Статус
 
     def __repr__(self):
         return '<DormitoryRoom {} (id={} dormitory_id={} floor={} size={} status={}>'.format(self, self.id, self.dormitory_id, self.floor, self.size, self.status)
